AITypingState enum

The current typing state of the AI assistant.

This is used to determine the state of the AI assistant when it's generating a response for the provided query.

Inheritance
Available extensions

Values

idle → const AITypingState

The AI assistant is idle.

error → const AITypingState

The AI assistant is in an error state.

checkingSources → const AITypingState

The AI assistant is checking external sources.

thinking → const AITypingState

The AI assistant is thinking.

generating → const AITypingState

The AI assistant is generating a response.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AITypingState>
A constant List of the values in this enum, in order of their declaration.