CompletedState class sealed

Represents the completed state of a message.

Annotations
  • @freezed

Constructors

CompletedState.deleted({@Default.new(false) bool hard})
Deleted state when the message has been successfully deleted.
const
factory
CompletedState.fromJson(Map<String, dynamic> json)
Creates a new instance from a json
factory
CompletedState.sent()
Sent state when the message has been successfully sent.
const
factory
CompletedState.updated()
Updated state when the message has been successfully updated.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CompletedState to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited