MessageDelivery class

A delivery receipt for a message in a channel.

Used to acknowledge that the current user has received a message, notifying the sender that their message was delivered.

Annotations
  • @JsonSerializable.new(createFactory: false)

Constructors

MessageDelivery({required String channelCid, required String messageId})
Creates a delivery receipt for a message.
const

Properties

channelCid String
The channel identifier containing the message.
final
hashCode int
The hash code for this object.
no setterinherited
messageId String
The identifier of the message received.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this MessageDelivery to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited