PollOption class

A model class representing a poll option.

Annotations
  • @JsonSerializable.new()

Constructors

PollOption({String? id, required String text, Map<String, Object?> extraData = const {}})
A model class representing a poll option.
const
PollOption.fromJson(Map<String, dynamic> json)
Create a new instance from a json
factory

Properties

extraData → Map<String, Object?>
Map of custom poll option extraData
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the poll option.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
text → String
The text describing the poll option.
final

Methods

copyWith({Object? id = _nullConst, String? text, Map<String, Object?>? extraData}) → PollOption
Creates a copy of PollOption with specified attributes overridden.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to json
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

topLevelFields → const List<String>
Known top level fields.