QueryChannelsResult class

The result of a queryChannelsWithResult call on StreamChatClient.

Carries the live Channel instances matching the query alongside the server-resolved PredefinedFilter spec (when one is associated with the query).

Constructors

QueryChannelsResult({required List<Channel> channels, PredefinedFilter? predefinedFilter})
Creates a new QueryChannelsResult.
const

Properties

channels List<Channel>
The live Channel instances matching the query.
final
hashCode int
The hash code for this object.
no setterinherited
predefinedFilter PredefinedFilter?
The server-resolved predefined-filter spec, or null when the query did not use a predefinedFilter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited