Read class
The class that defines a read event
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastDeliveredAt → DateTime?
-
Date of the last delivered message
final
- lastDeliveredMessageId → String?
-
The id of the last delivered message
final
- lastRead → DateTime
-
Date of the read event
final
- lastReadMessageId → String?
-
The id of the last read message
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - unreadMessages → int
-
Number of unread messages
final
- user → User
-
User who sent the event
final
Methods
-
copyWith(
{DateTime? lastRead, String? lastReadMessageId, User? user, int? unreadMessages, DateTime? lastDeliveredAt, String? lastDeliveredMessageId}) → Read - Creates a copy of Read with specified attributes overridden.
-
merge(
Read? other) → Read -
Creates a new Read which is the merge of this and
other. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to json
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited