ThreadParticipant class
A model class representing a user that is participating in a thread.
- Annotations
-
- @JsonSerializable.new()
Constructors
- ThreadParticipant({required String channelCid, required DateTime createdAt, required DateTime lastReadAt, DateTime? lastThreadMessageAt, DateTime? leftThreadAt, String? threadId, String? userId, User? user})
-
A model class representing a user that is participating in a thread.
const
-
ThreadParticipant.fromJson(Map<
String, dynamic> json) -
Create a new instance from a json
factory
Properties
- channelCid → String
-
The channel cid this thread participant belongs to.
final
- createdAt → DateTime
-
The date at which the thread participant was created.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastReadAt → DateTime
-
The date at which the user last read the thread.
final
- lastThreadMessageAt → DateTime?
-
The date at which the user last sent a message in the thread.
final
- leftThreadAt → DateTime?
-
The date at which the user left the thread.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - threadId → String?
-
The id of the thread this participant belongs to.
final
- user → User?
-
The user participating in the thread.
final
- userId → String?
-
The id of the user participating in the thread.
final
Methods
-
copyWith(
{String? channelCid, DateTime? createdAt, DateTime? lastReadAt, DateTime? lastThreadMessageAt, DateTime? leftThreadAt, String? threadId, String? userId, User? user}) → ThreadParticipant - Creates a copy of this ThreadParticipant with specified attributes overridden.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to json
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited